==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceDefinitionSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.util.Collection;

public interface V1beta1CustomResourceDefinitionSpecFluent<A extends V1beta1CustomResourceDefinitionSpecFluent<A>> extends Fluent<A>{


    public A addToAdditionalPrinterColumns(int index,V1beta1CustomResourceColumnDefinition item);
    public A setToAdditionalPrinterColumns(int index,V1beta1CustomResourceColumnDefinition item);
    public A addToAdditionalPrinterColumns(V1beta1CustomResourceColumnDefinition... items);
    public A addAllToAdditionalPrinterColumns(Collection<V1beta1CustomResourceColumnDefinition> items);
    public A removeFromAdditionalPrinterColumns(V1beta1CustomResourceColumnDefinition... items);
    public A removeAllFromAdditionalPrinterColumns(Collection<V1beta1CustomResourceColumnDefinition> items);
    
/**
 * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CustomResourceColumnDefinition> getAdditionalPrinterColumns();
    public List<V1beta1CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
    public V1beta1CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
    public V1beta1CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
    public V1beta1CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
    public V1beta1CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceColumnDefinitionBuilder> predicate);
    public A withAdditionalPrinterColumns(List<V1beta1CustomResourceColumnDefinition> additionalPrinterColumns);
    public A withAdditionalPrinterColumns(V1beta1CustomResourceColumnDefinition... additionalPrinterColumns);
    public Boolean hasAdditionalPrinterColumns();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(V1beta1CustomResourceColumnDefinition item);
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,V1beta1CustomResourceColumnDefinition item);
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceColumnDefinitionBuilder> predicate);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    
/**
 * This method has been deprecated, please use method buildNames instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceDefinitionNames getNames();
    public V1beta1CustomResourceDefinitionNames buildNames();
    public A withNames(V1beta1CustomResourceDefinitionNames names);
    public Boolean hasNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNamesLike(V1beta1CustomResourceDefinitionNames item);
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> editNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNamesLike(V1beta1CustomResourceDefinitionNames item);
    public String getScope();
    public A withScope(String scope);
    public Boolean hasScope();
    
/**
 * This method has been deprecated, please use method buildSubresources instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceSubresources getSubresources();
    public V1beta1CustomResourceSubresources buildSubresources();
    public A withSubresources(V1beta1CustomResourceSubresources subresources);
    public Boolean hasSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresourcesLike(V1beta1CustomResourceSubresources item);
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresourcesLike(V1beta1CustomResourceSubresources item);
    
/**
 * This method has been deprecated, please use method buildValidation instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceValidation getValidation();
    public V1beta1CustomResourceValidation buildValidation();
    public A withValidation(V1beta1CustomResourceValidation validation);
    public Boolean hasValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidationLike(V1beta1CustomResourceValidation item);
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> editValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidationLike(V1beta1CustomResourceValidation item);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A addToVersions(int index,V1beta1CustomResourceDefinitionVersion item);
    public A setToVersions(int index,V1beta1CustomResourceDefinitionVersion item);
    public A addToVersions(V1beta1CustomResourceDefinitionVersion... items);
    public A addAllToVersions(Collection<V1beta1CustomResourceDefinitionVersion> items);
    public A removeFromVersions(V1beta1CustomResourceDefinitionVersion... items);
    public A removeAllFromVersions(Collection<V1beta1CustomResourceDefinitionVersion> items);
    
/**
 * This method has been deprecated, please use method buildVersions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CustomResourceDefinitionVersion> getVersions();
    public List<V1beta1CustomResourceDefinitionVersion> buildVersions();
    public V1beta1CustomResourceDefinitionVersion buildVersion(int index);
    public V1beta1CustomResourceDefinitionVersion buildFirstVersion();
    public V1beta1CustomResourceDefinitionVersion buildLastVersion();
    public V1beta1CustomResourceDefinitionVersion buildMatchingVersion(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionVersionBuilder> predicate);
    public A withVersions(List<V1beta1CustomResourceDefinitionVersion> versions);
    public A withVersions(V1beta1CustomResourceDefinitionVersion... versions);
    public Boolean hasVersions();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersion();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersionLike(V1beta1CustomResourceDefinitionVersion item);
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> setNewVersionLike(int index,V1beta1CustomResourceDefinitionVersion item);
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editVersion(int index);
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editFirstVersion();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editLastVersion();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editMatchingVersion(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionVersionBuilder> predicate);

    public interface AdditionalPrinterColumnsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceColumnDefinitionFluent<V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<N>>{

        
    public N and();    public N endAdditionalPrinterColumn();
}
    public interface NamesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionNamesFluent<V1beta1CustomResourceDefinitionSpecFluent.NamesNested<N>>{

        
    public N and();    public N endNames();
}
    public interface SubresourcesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceSubresourcesFluent<V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<N>>{

        
    public N and();    public N endSubresources();
}
    public interface ValidationNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceValidationFluent<V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<N>>{

        
    public N and();    public N endValidation();
}
    public interface VersionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionVersionFluent<V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<N>>{

        
    public N and();    public N endVersion();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceDefinitionSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1beta1CustomResourceDefinitionSpecFluent<A extends V1beta1CustomResourceDefinitionSpecFluent<A>> extends Fluent<A>{


    public A addToAdditionalPrinterColumns(int index,V1beta1CustomResourceColumnDefinition item);
    public A setToAdditionalPrinterColumns(int index,V1beta1CustomResourceColumnDefinition item);
    public A addToAdditionalPrinterColumns(V1beta1CustomResourceColumnDefinition... items);
    public A addAllToAdditionalPrinterColumns(Collection<V1beta1CustomResourceColumnDefinition> items);
    public A removeFromAdditionalPrinterColumns(V1beta1CustomResourceColumnDefinition... items);
    public A removeAllFromAdditionalPrinterColumns(Collection<V1beta1CustomResourceColumnDefinition> items);
    
/**
 * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CustomResourceColumnDefinition> getAdditionalPrinterColumns();
    public List<V1beta1CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
    public V1beta1CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
    public V1beta1CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
    public V1beta1CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
    public V1beta1CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean hasMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceColumnDefinitionBuilder> predicate);
    public A withAdditionalPrinterColumns(List<V1beta1CustomResourceColumnDefinition> additionalPrinterColumns);
    public A withAdditionalPrinterColumns(V1beta1CustomResourceColumnDefinition... additionalPrinterColumns);
    public Boolean hasAdditionalPrinterColumns();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(V1beta1CustomResourceColumnDefinition item);
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,V1beta1CustomResourceColumnDefinition item);
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
    public V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceColumnDefinitionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConversion instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceConversion getConversion();
    public V1beta1CustomResourceConversion buildConversion();
    public A withConversion(V1beta1CustomResourceConversion conversion);
    public Boolean hasConversion();
    public V1beta1CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversion();
    public V1beta1CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversionLike(V1beta1CustomResourceConversion item);
    public V1beta1CustomResourceDefinitionSpecFluent.ConversionNested<A> editConversion();
    public V1beta1CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversion();
    public V1beta1CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversionLike(V1beta1CustomResourceConversion item);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(String arg1);
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNames instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceDefinitionNames getNames();
    public V1beta1CustomResourceDefinitionNames buildNames();
    public A withNames(V1beta1CustomResourceDefinitionNames names);
    public Boolean hasNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNamesLike(V1beta1CustomResourceDefinitionNames item);
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> editNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNames();
    public V1beta1CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNamesLike(V1beta1CustomResourceDefinitionNames item);
    public String getScope();
    public A withScope(String scope);
    public Boolean hasScope();
    public A withNewScope(String arg1);
    public A withNewScope(StringBuilder arg1);
    public A withNewScope(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSubresources instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceSubresources getSubresources();
    public V1beta1CustomResourceSubresources buildSubresources();
    public A withSubresources(V1beta1CustomResourceSubresources subresources);
    public Boolean hasSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresourcesLike(V1beta1CustomResourceSubresources item);
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresources();
    public V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresourcesLike(V1beta1CustomResourceSubresources item);
    
/**
 * This method has been deprecated, please use method buildValidation instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceValidation getValidation();
    public V1beta1CustomResourceValidation buildValidation();
    public A withValidation(V1beta1CustomResourceValidation validation);
    public Boolean hasValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidationLike(V1beta1CustomResourceValidation item);
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> editValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidation();
    public V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidationLike(V1beta1CustomResourceValidation item);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(String arg1);
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(StringBuffer arg1);
    public A addToVersions(int index,V1beta1CustomResourceDefinitionVersion item);
    public A setToVersions(int index,V1beta1CustomResourceDefinitionVersion item);
    public A addToVersions(V1beta1CustomResourceDefinitionVersion... items);
    public A addAllToVersions(Collection<V1beta1CustomResourceDefinitionVersion> items);
    public A removeFromVersions(V1beta1CustomResourceDefinitionVersion... items);
    public A removeAllFromVersions(Collection<V1beta1CustomResourceDefinitionVersion> items);
    
/**
 * This method has been deprecated, please use method buildVersions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CustomResourceDefinitionVersion> getVersions();
    public List<V1beta1CustomResourceDefinitionVersion> buildVersions();
    public V1beta1CustomResourceDefinitionVersion buildVersion(int index);
    public V1beta1CustomResourceDefinitionVersion buildFirstVersion();
    public V1beta1CustomResourceDefinitionVersion buildLastVersion();
    public V1beta1CustomResourceDefinitionVersion buildMatchingVersion(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionVersionBuilder> predicate);
    public Boolean hasMatchingVersion(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionVersionBuilder> predicate);
    public A withVersions(List<V1beta1CustomResourceDefinitionVersion> versions);
    public A withVersions(V1beta1CustomResourceDefinitionVersion... versions);
    public Boolean hasVersions();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersion();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersionLike(V1beta1CustomResourceDefinitionVersion item);
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> setNewVersionLike(int index,V1beta1CustomResourceDefinitionVersion item);
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editVersion(int index);
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editFirstVersion();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editLastVersion();
    public V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<A> editMatchingVersion(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionVersionBuilder> predicate);

    public interface AdditionalPrinterColumnsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceColumnDefinitionFluent<V1beta1CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<N>>{

        
    public N and();    public N endAdditionalPrinterColumn();
}
    public interface ConversionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceConversionFluent<V1beta1CustomResourceDefinitionSpecFluent.ConversionNested<N>>{

        
    public N and();    public N endConversion();
}
    public interface NamesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionNamesFluent<V1beta1CustomResourceDefinitionSpecFluent.NamesNested<N>>{

        
    public N and();    public N endNames();
}
    public interface SubresourcesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceSubresourcesFluent<V1beta1CustomResourceDefinitionSpecFluent.SubresourcesNested<N>>{

        
    public N and();    public N endSubresources();
}
    public interface ValidationNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceValidationFluent<V1beta1CustomResourceDefinitionSpecFluent.ValidationNested<N>>{

        
    public N and();    public N endValidation();
}
    public interface VersionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionVersionFluent<V1beta1CustomResourceDefinitionSpecFluent.VersionsNested<N>>{

        
    public N and();    public N endVersion();
}


}
